@@ -3,5 +3,5 @@ test_that("Verifying message output for report creation", {
 })
 
 test_that("Checking error if incorrect value in columns", {
-  expect_error(readMWRresultsview(respth, columns = c("Characeristic Name"), outputdir = tempdir()))
+  expect_error(readMWRresultsview(respth, columns = c("Characeristic Name"), output_dir = tempdir()))
 })
\ No newline at end of file
