@@ -2,6 +2,11 @@ test_that("Verifying message output for wqx table creation", {
   expect_message(tabMWRwqx(respth, accpth, sitpth, wqxpth, warn = TRUE, runchk = F, output_dir = tempdir()))
 })
 
+test_that("Verifying message output for wqx table creation, no QC reference values", {
+  reschk <- resdat[is.na(resdat$`QC Reference Value`), ]
+  expect_message(tabMWRwqx(reschk, accpth, sitpth, wqxpth, warn = TRUE, runchk = F, output_dir = tempdir()))
+})
+
 test_that("Check warning if UQL or MDL missing from accdat", {
   accchk <- accdat %>% 
     mutate(
