@@ -3,6 +3,11 @@ test_that("title with parameter only", {
   expect_equal(result, 'DO')
 })
 
+test_that("title with parameter and summary function", {
+  result <- utilMWRtitle(param = 'DO', accdat = accdat, sumfun = "auto")
+  expect_equal(result, 'DO (mean)')
+})
+
 test_that("title with parameter, date filter only", {
   result <- utilMWRtitle(param = 'DO', dtrng = c('2021-05-01', '2021-07-31'))
   expect_equal(result, 'DO, data filtered by dates (1 May, 2021 to 31 July, 2021)')
